// Classe:       Data
// Autor:        Armando Delgado

#ifndef __DATA__
#define __DATA__

#include <string>
using namespace std;


// Tipo struct para representacao interna de datas
typedef struct {int dia, mes, ano;} Date;

/* Classe:          Data
 * Autor:           Armando Delgado
 *
 * Descricao:       tipo abstrato para manipulacao de datas.
 * Construtores:    Data() e Data(string)
 * Destrutor:       nenhum
 *                       
 */
class Data {
 private:
  Date data;    // data como dia, mes e ano
  
 public:
  
  // Construtor padrao que define o valor inicial 
  // como sendo a data corrente
  Data();

  // Construtor que define o valor inicial a partir de um string.
  // O formato deste string deve ser "D[D]/M[M]/[AA]AA"
  // ou "DIA de MES de ANO".
  Data (string nData);

  // Define uma data a partir de um string. O formato deste string
  // pode ser "D[D]/M[M]/[AA]AA" ou "DIA de MES de ANO"
  void setData(string nData);

  // Retorna o valor da data como um string no 
  // formato "DD/MM/AAAA"
  string getData() const;

  // Retorna o valor da data como um string no 
  // formato "DIA de MES de ANO"
  string getDataExtenso() const;

  // Soma data com um numero de dias
  Data operator +(int nDias) const;

  // Subtrai um numero de dias da data
  Data operator -(int nDias) const;

  // Soma data com um numero de dias, meses e anos,
  // expressos como um objeto Data.
  Data operator +(Data nDias) const;

  // Subtrai um numero de dias, meses e anos da data.
  Data operator -(Data nDias) const;

  // Indica se data eh diferente de uma data fornecida.
  bool operator !=(Data nDias) const;

  // Indica se data eh igual a uma data fornecida.
  bool operator ==(Data nDias) const;

  // Indica se data eh posterior a uma data fornecida.
  bool operator >(Data nDias) const;

  // Indica se data eh anterior a uma data fornecida.
  bool operator <(Data nDias) const;
};

#endif



